pub trait Insert<K>: KeyedCollection {
// Required method
fn insert(&mut self, key: K, value: Self::Value);
}Expand description
Insert a new key-value pair into the collection at an arbitrary key.
pub trait Insert<K>: KeyedCollection {
// Required method
fn insert(&mut self, key: K, value: Self::Value);
}Insert a new key-value pair into the collection at an arbitrary key.