KeyedCollection

Trait KeyedCollection 

pub trait KeyedCollection {
    type Key;
    type Value;
}
A keyed collection without any operations defined.

A keyed collection is just a key-value map. We however use the name KeyedCollection instead of Map to distinguish maps from vectors and stable vectors, which also are keyed collections but with slightly different sets of operations.

Required Associated Types

type Key

Type of the keys in the keyed collection.

type Value

Type of the values in the keyed collection.

Implementations on Foreign Types

Source

impl<K> KeyedCollection for BTreeSet<K>

Source

impl<K> KeyedCollection for HashSet<K>

Source

impl<K, V> KeyedCollection for BTreeMap<K, V>

Source

type Key = K

Source

type Value = V

Source

impl<K, V> KeyedCollection for HashMap<K, V>

Source

type Key = K

Source

type Value = V

Source

impl<K: RTreeObject> KeyedCollection for RTree<K>

Source

impl<V> KeyedCollection for Vec<V>

Source

impl<V> KeyedCollection for Arena<V>

Source

impl<V, C: Core<V>> KeyedCollection for StableVecFacade<V, C>

Implementors