pub trait Set<K>: Container {
// Required method
fn set(&mut self, key: K, value: Self::Value);
}Expand description
Set the value of an already existing element under a key.
pub trait Set<K>: Container {
// Required method
fn set(&mut self, key: K, value: Self::Value);
}Set the value of an already existing element under a key.