pub trait KeyedCollection {
type Key;
type Value;
}Expand description
A keyed collection without any operations defined.
A keyed collection is just a key-value map. We however use the name
KeyedCollection instead of Map to distinguish maps from vectors and
stable vectors, which also are keyed collections but with slightly different
sets of operations.